#include "emu.h"
#include "classic.h"

#undef sin
#undef cos

#include <graphx.h>
#include <keypadc.h>
#include <fontlibc.h>
#include <debug.h>
#include <tice.h>
#include <cstring>
#include <cmath>

#include "gfx/gfx.h"
#include "profiler.h"
#include "practice.h"

#define BASE_X ((LCD_WIDTH - 128 * 2) / 4)
#define BASE_Y ((LCD_HEIGHT - 128 * 2) / 4)

#define SCREEN_X(x0) ((x0) + offset.x)
#define SCREEN_Y(y0) ((y0) + offset.y)

#define FRAMESKIP 1
#define FRAME_TIMER 0

#define SAVE_NAME "CelesteS"

static struct {
    int x;
    int y;
} offset = {BASE_X, BASE_Y};

static int gameFrame = 0;
static int timerOffset = 0;

const uint8_t mask[] = {
        0, 0, 0,  0,  0,  0,  0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
        4, 2, 0,  0,  0,  0,  0, 0, 0, 0, 0, 2, 0, 0, 0, 0,
        3, 3, 3,  3,  3,  3,  3, 3, 4, 4, 4, 2, 2, 0, 0, 0,
        3, 3, 3,  3,  3,  3,  3, 3, 4, 4, 4, 2, 2, 2, 2, 2,
        0, 0, 19, 19, 19, 19, 2, 2, 3, 2, 2, 2, 2, 2, 2, 2,
        0, 0, 19, 19, 19, 19, 2, 2, 4, 2, 2, 2, 2, 2, 2, 2,
        0, 0, 19, 19, 19, 19, 0, 4, 4, 2, 2, 2, 2, 2, 2, 2,
        0, 0, 19, 19, 19, 19, 0, 0, 0, 2, 2, 2, 2, 2, 2, 2
};

static uint8_t pal_map[16] = {0x00, 0x11, 0x22, 0x33, 0x44, 0x55, 0x66, 0x77, 0x88, 0x99, 0xAA, 0xBB, 0xCC, 0xDD, 0xEE, 0xFF};
static bool default_pal = true;

static uint8_t font_data[] = {
#include "font.inc"
};

void init() {
    kb_SetMode(MODE_3_CONTINUOUS);
    gfx_ZeroScreen();
    gfx_SetDrawBuffer();
    gfx_ZeroScreen();
    gfx_SetPalette(mypalette, sizeof mypalette, 0);
    gfx_SetClipRegion(BASE_X, 0,
                      BASE_X + 128, LCD_HEIGHT);
    lcd_Control = 0x13925; // 4 bpp mode
    fontlib_SetFont(reinterpret_cast<const fontlib_font_t *>(font_data), static_cast<fontlib_load_options_t>(0));
    fontlib_SetTransparency(true);
    gen_lookups();
    profiler_init();
    FILE *save = fopen(SAVE_NAME, "r");
    _init(save);
    if(save) {
        fclose(save);
        remove(SAVE_NAME);
    }
}

void update() {
    timer_Set(1, 0);
    profiler_add(total);

    gameFrame++;
#if FRAMESKIP
    timerOffset -= 32768 / 30;
#endif
    _update();
    practice_update();

    if(freeze <= 0 && (!FRAMESKIP || timerOffset < 32768 / 30)) {
        // draw
        _draw();
        profiler_add(hud);
        practice_draw_hud();
        profiler_end(hud);
        profiler_add(deinterlace);
        for(uint8_t y = 0; y < LCD_HEIGHT / 2; y++) {
            memcpy(&gfx_vbuffer[y][LCD_WIDTH / 2 + BASE_X], &gfx_vbuffer[y][BASE_X], LCD_WIDTH / 2 - BASE_X * 2);
        }
        profiler_end(deinterlace);
#if FRAME_TIMER
        gfx_SetColor(0);
        gfx_FillRectangle_NoClip(0, 0, 16, 12);
        gfx_SetTextFGColor(0x77);
        uint24_t t = timer_Get(1) / 33;
        gfx_SetTextXY(0, 0);
        gfx_PrintUInt(t, 1);
#endif
        gfx_SwapDraw();
    }
    profiler_end(total);
    if(kb_IsDown(kb_KeyTrace)) profiler_print();
    do {
        if(kb_IsDown(kb_KeyClear)) return;
    } while(FRAMESKIP && (int)(timerOffset + timer_Get(1)) < 0);
    profiler_tick();
    timerOffset += timer_Get(1);
}

void save_game() {
    if(!needs_save()) return;
    FILE *save = fopen("CelesteS", "w");
    if(!save) return;
    store_save(save);
    fclose(save);
}

void color(uint8_t c) {
    gfx_SetColor(pal_map[c]);
    fontlib_SetForegroundColor(pal_map[c]);
}

void print(const char *str) {
    int orig_x = fontlib_GetCursorX();
    fontlib_DrawString(str);
    if(orig_x < BASE_X) {
        gfx_SetColor(0);
        gfx_FillRectangle_NoClip(orig_x, fontlib_GetCursorY(), BASE_X - orig_x, 5);
    }
    int new_x = fontlib_GetCursorX();
    if(new_x > BASE_X + 128) {
        gfx_SetColor(0);
        gfx_FillRectangle_NoClip(BASE_X + 128, fontlib_GetCursorY(), new_x - BASE_X - 128, 5);
    }
}

void print(const char *str, int x, int y, uint8_t col) {
    color(col);
    fontlib_SetCursorPosition(SCREEN_X(x - 1), SCREEN_Y(y));
    print(str);
}

void print(char chr, int x, int y, uint8_t col) {
    color(col);
    fontlib_SetCursorPosition(SCREEN_X(x - 1), SCREEN_Y(y));
    fontlib_DrawGlyph(chr);
}

void print_int(int n, int x, int y, uint8_t col, int l) {
    fontlib_SetCursorPosition(SCREEN_X(x - 1), SCREEN_Y(y));
    color(col);
    print_int(n, l);
}

void print_int(int n, int x, int y, uint8_t col) {
    print_int(n, x, y, col, 1);
}

void print_int(int n) {
    print_int(n, 1);
}

void print_int(int n, int l) {
    fontlib_DrawUInt(n, l);
}

void rectfill(int x0, int y0, int x1, int y1, uint8_t col) {
    color(col);
    gfx_FillRectangle(SCREEN_X(x0), SCREEN_Y(y0), x1 - x0 + 1, y1 - y0 + 1);
}

void circfill(int x, int y, int radius, int col) {
    color(col);
    gfx_FillCircle(SCREEN_X(x), SCREEN_Y(y), radius);
}

void draw_plus(int x, int y, int col) {
    color(col);
    gfx_SetPixel(SCREEN_X(x), SCREEN_Y(y));
    gfx_SetPixel(SCREEN_X(x + 1), SCREEN_Y(y));
    gfx_SetPixel(SCREEN_X(x - 1), SCREEN_Y(y));
    gfx_SetPixel(SCREEN_X(x), SCREEN_Y(y + 1));
    gfx_SetPixel(SCREEN_X(x), SCREEN_Y(y - 1));
}

void vert_line(int x, int y0, int y1, int col) {
    color(col);
    if(y0 < y1) {
        gfx_VertLine(SCREEN_X(x), SCREEN_Y(y0), SCREEN_Y(y1 - y0));
    } else {
        gfx_VertLine(SCREEN_X(x), SCREEN_Y(y1), SCREEN_Y(y0 - y1));
    }
}

void camera() {
    camera(0, 0);
}

void camera(int x, int y) {
    offset.x = x + BASE_X;
    offset.y = y + BASE_Y;
}

bool fget(uint8_t tile, uint8_t flag) {
    return (mask[tile] & (1 << flag)) != 0;
}

gfx_rletsprite_t *render_map(int cell_x, int cell_y, uint8_t layers) {
    gfx_SetColor(0);
    gfx_FillRectangle_NoClip(LCD_WIDTH / 2, 0, 128, 128);
    for(int y = 0; y < 16; y++) {
        for(int x = 0; x < 16; x++) {
            uint8_t tile = tilemap[x + cell_x + (y + cell_y) * 128];
            // I don't think this is how the PICO-8 actually handles the layers argument but whatevs
            if(tile && fget(tile, layers)) {
                gfx_TransparentSprite_NoClip(atlas_tiles[tile], LCD_WIDTH / 2 + x * 8, y * 8);
            }
        }
    }
    auto *sprite = (gfx_sprite_t*)&gfx_vbuffer[128][0];
    sprite->width = 128;
    sprite->height = 128;
    gfx_GetSprite(sprite, LCD_WIDTH / 2, 0);
    return gfx_ConvertMallocRLETSprite(sprite);
}

void map(int cell_x, int cell_y, int sx, int sy, uint8_t layers) {
    profiler_add(map);
    static struct {
        int x;
        int y;
        gfx_rletsprite_t *sprite;
    } cache[3] = {};
    auto entry = &cache[layers - 1];
    if(entry->x != cell_x || entry->y != cell_y || !entry->sprite) {
        entry->x = cell_x;
        entry->y = cell_y;
        free(entry->sprite);
        entry->sprite = render_map(cell_x, cell_y, layers);
    }
    if(entry->sprite) {
        gfx_RLETSprite(entry->sprite, SCREEN_X(sx), SCREEN_Y(sy));
    }
    profiler_end(map);
}

void spr(uint8_t n, int x, int y) {
    spr(n, x, y, 1, 1, false, false);
}

void spr(uint8_t n, int x, int y, uint8_t w, uint8_t h, bool flip_x, bool flip_y) {
    (void)w,(void)h;
    profiler_add(spr);
    gfx_sprite_t *sprite = atlas_tiles[n];
    gfx_TempSprite(temp, 8, 8);
    if(flip_x) {
        gfx_FlipSpriteY(sprite, temp);
    } else if(flip_y) {
        gfx_FlipSpriteX(sprite, temp);
    } else {
        memcpy(&temp_data, sprite, sizeof temp_data);
    }
    if(!default_pal) {
        for(uint8_t i = 0; i < 64; i++) {
            // this is probably slow
            temp->data[i] = pal_map[temp->data[i] & 0xF];
        }
    }
    // todo: both?
    gfx_TransparentSprite(temp, SCREEN_X(x), SCREEN_Y(y));
    profiler_end(spr);
}

void pal() {
    gfx_SetPalette(mypalette, sizeof mypalette, 0);
    for(uint8_t i = 0; i < 16; i++) {
        pal_map[i] = i | (i << 4);
    }
    default_pal = true;
}

void pal(int c0, int c1) {
    pal_map[c0] = c1 | (c1 << 4);
    default_pal = c0 == c1;
}

void pal(int c0, int c1, int p) {
    if(p == 0) {
        pal(c0, c1);
    } else {
        gfx_palette[c0] = mypalette[c1];
        default_pal = c0 == c1;
    }
}


bool btn(uint8_t index) {
    kb_lkey_t keys[6] = {kb_KeyLeft, kb_KeyRight, kb_KeyUp, kb_KeyDown, kb_Key2nd, kb_KeyAlpha};
    if(index > 5) return false;
    return kb_IsDown(keys[index]);
}

int rnd(int max) {
    return randInt(0, max);
}

int min(int a, int b) {
    return a <= b ? a : b;
}

int max(int a, int b) {
    return a >= b ? a : b;
}

int sin_table[TRIG_PRECISION / 4];

void gen_lookups() {
    for(unsigned i = 0; i < TRIG_PRECISION / 4; i++) {
        sin_table[i] = sin(i * M_PI / (TRIG_PRECISION / 2.0)) * TRIG_SCALE;
    }
}

int fast_sin(unsigned angle) {
    angle >>= 24 - TRIG_PRECISION_BITS;
    if(angle < TRIG_PRECISION / 4) return sin_table[angle];
    if(angle == TRIG_PRECISION / 4) return TRIG_SCALE;
    if(angle < TRIG_PRECISION / 2) return sin_table[TRIG_PRECISION / 2 - angle];
    if(angle < TRIG_PRECISION * 3 / 4) return -sin_table[angle - TRIG_PRECISION / 2];
    if(angle == TRIG_PRECISION * 3 / 4) return -TRIG_SCALE;
    return -sin_table[TRIG_PRECISION - angle];
}

const uint8_t tilemap[
        64 * 128] = {0x23, 0x31, 0x25, 0x25, 0x48, 0x25, 0x25, 0x32, 0x32, 0x32, 0x32, 0x32, 0x33, 0x00, 0x00, 0x24,
                     0x25, 0x26, 0x24, 0x25, 0x25, 0x26, 0x31, 0x32, 0x32, 0x32, 0x25, 0x26, 0x28, 0x28, 0x28, 0x24,
                     0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x32, 0x33, 0x28, 0x38, 0x28, 0x28, 0x31, 0x25, 0x25, 0x25,
                     0x32, 0x32, 0x32, 0x32, 0x33, 0x00, 0x00, 0x00, 0x31, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32,
                     0x32, 0x33, 0x00, 0x00, 0x00, 0x24, 0x32, 0x32, 0x32, 0x33, 0x31, 0x32, 0x32, 0x32, 0x25, 0x25,
                     0x25, 0x25, 0x25, 0x48, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x26, 0x28, 0x28, 0x24, 0x25,
                     0x25, 0x48, 0x25, 0x25, 0x25, 0x26, 0x28, 0x28, 0x28, 0x28, 0x24, 0x25, 0x48, 0x25, 0x25, 0x25,
                     0x26, 0x28, 0x28, 0x28, 0x28, 0x31, 0x32, 0x32, 0x32, 0x25, 0x48, 0x25, 0x25, 0x25, 0x25, 0x25,
                     0x25, 0x23, 0x31, 0x32, 0x32, 0x32, 0x33, 0x29, 0x00, 0x00, 0x28, 0x29, 0x00, 0x00, 0x00, 0x24,
                     0x25, 0x26, 0x31, 0x32, 0x32, 0x33, 0x28, 0x28, 0x00, 0x28, 0x24, 0x26, 0x2a, 0x10, 0x28, 0x24,
                     0x25, 0x48, 0x25, 0x25, 0x25, 0x26, 0x00, 0x2a, 0x28, 0x28, 0x29, 0x28, 0x10, 0x24, 0x48, 0x25,
                     0x28, 0x28, 0x28, 0x29, 0x00, 0x00, 0x00, 0x00, 0x28, 0x28, 0x29, 0x00, 0x00, 0x00, 0x00, 0x00,
                     0x28, 0x10, 0x00, 0x00, 0x00, 0x37, 0x28, 0x29, 0x00, 0x00, 0x00, 0x00, 0x2a, 0x28, 0x31, 0x48,
                     0x25, 0x25, 0x25, 0x25, 0x25, 0x48, 0x25, 0x25, 0x32, 0x32, 0x32, 0x33, 0x28, 0x28, 0x24, 0x25,
                     0x25, 0x25, 0x48, 0x25, 0x32, 0x33, 0x38, 0x28, 0x2a, 0x28, 0x31, 0x32, 0x25, 0x25, 0x48, 0x25,
                     0x26, 0x28, 0x38, 0x28, 0x28, 0x28, 0x2a, 0x2a, 0x28, 0x31, 0x32, 0x32, 0x32, 0x32, 0x25, 0x25,
                     0x25, 0x25, 0x23, 0x20, 0x10, 0x28, 0x38, 0x00, 0x00, 0x00, 0x2a, 0x00, 0x00, 0x00, 0x3d, 0x24,
                     0x25, 0x25, 0x23, 0x20, 0x10, 0x28, 0x29, 0x29, 0x00, 0x28, 0x24, 0x26, 0x00, 0x3a, 0x38, 0x24,
                     0x25, 0x25, 0x25, 0x48, 0x25, 0x33, 0x00, 0x00, 0x29, 0x00, 0x00, 0x2a, 0x00, 0x31, 0x25, 0x25,
                     0x28, 0x38, 0x29, 0x00, 0x00, 0x3a, 0x67, 0x68, 0x38, 0x28, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
                     0x38, 0x28, 0x39, 0x3e, 0x00, 0x3a, 0x28, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x28, 0x00, 0x24,
                     0x25, 0x25, 0x32, 0x32, 0x32, 0x32, 0x32, 0x33, 0x21, 0x22, 0x22, 0x23, 0x28, 0x28, 0x24, 0x25,
                     0x25, 0x25, 0x32, 0x33, 0x28, 0x28, 0x28, 0x29, 0x00, 0x00, 0x2a, 0x28, 0x31, 0x32, 0x25, 0x25,
                     0x26, 0x28, 0x28, 0x28, 0x28, 0x29, 0x00, 0x00, 0x2a, 0x28, 0x28, 0x28, 0x38, 0x28, 0x24, 0x48,
                     0x32, 0x32, 0x33, 0x28, 0x28, 0x28, 0x29, 0x00, 0x00, 0x00, 0x00, 0x00, 0x3f, 0x20, 0x20, 0x24,
                     0x48, 0x25, 0x26, 0x28, 0x28, 0x29, 0x00, 0x00, 0x00, 0x2a, 0x24, 0x33, 0x00, 0x00, 0x2a, 0x24,
                     0x25, 0x32, 0x25, 0x25, 0x26, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x31, 0x25,
                     0x29, 0x00, 0x00, 0x00, 0x00, 0x21, 0x22, 0x23, 0x28, 0x28, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
                     0x2a, 0x28, 0x28, 0x34, 0x35, 0x36, 0x29, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x28, 0x39, 0x24,
                     0x25, 0x26, 0x21, 0x22, 0x23, 0x20, 0x21, 0x23, 0x31, 0x32, 0x32, 0x33, 0x28, 0x28, 0x24, 0x25,
                     0x48, 0x26, 0x2b, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x1c, 0x00, 0x00, 0x3b, 0x24, 0x25,
                     0x26, 0x28, 0x28, 0x28, 0x00, 0x00, 0x00, 0x00, 0x00, 0x28, 0x28, 0x28, 0x28, 0x28, 0x24, 0x25,
                     0x23, 0x40, 0x28, 0x38, 0x28, 0x29, 0x3a, 0x28, 0x39, 0x00, 0x00, 0x00, 0x34, 0x35, 0x22, 0x25,
                     0x25, 0x48, 0x26, 0x29, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x30, 0x00, 0x00, 0x00, 0x00, 0x24,
                     0x33, 0x00, 0x31, 0x25, 0x33, 0x3d, 0x3f, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x31,
                     0x00, 0x00, 0x1c, 0x3a, 0x3a, 0x31, 0x25, 0x26, 0x20, 0x28, 0x39, 0x00, 0x00, 0x00, 0x00, 0x00,
                     0x00, 0x10, 0x28, 0x28, 0x28, 0x29, 0x00, 0x00, 0x00, 0x00, 0x11, 0x11, 0x3a, 0x28, 0x28, 0x31,
                     0x32, 0x33, 0x24, 0x25, 0x26, 0x10, 0x31, 0x33, 0x20, 0x28, 0x28, 0x28, 0x28, 0x38, 0x24, 0x25,
                     0x25, 0x26, 0x2b, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x3b, 0x24, 0x25,
                     0x26, 0x2a, 0x28, 0x28, 0x67, 0x00, 0x16, 0x00, 0x2a, 0x28, 0x28, 0x38, 0x28, 0x28, 0x24, 0x25,
                     0x26, 0x3a, 0x28, 0x28, 0x28, 0x10, 0x28, 0x29, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x31, 0x25,
                     0x25, 0x32, 0x33, 0x00, 0x00, 0x00, 0x00, 0x11, 0x00, 0x00, 0x37, 0x00, 0x00, 0x00, 0x3e, 0x24,
                     0x00, 0x00, 0x00, 0x37, 0x21, 0x22, 0x23, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
                     0x39, 0x58, 0x68, 0x28, 0x28, 0x28, 0x24, 0x26, 0x28, 0x29, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
                     0x2a, 0x28, 0x28, 0x29, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x21, 0x23, 0x28, 0x38, 0x28, 0x29,
                     0x28, 0x28, 0x31, 0x32, 0x33, 0x28, 0x28, 0x29, 0x00, 0x2a, 0x00, 0x2a, 0x28, 0x28, 0x24, 0x25,
                     0x25, 0x33, 0x2b, 0x0c, 0x00, 0x00, 0x00, 0x11, 0x11, 0x00, 0x00, 0x00, 0x0c, 0x3b, 0x31, 0x48,
                     0x26, 0x11, 0x28, 0x10, 0x00, 0x00, 0x00, 0x00, 0x68, 0x28, 0x28, 0x28, 0x28, 0x28, 0x24, 0x25,
                     0x25, 0x22, 0x35, 0x35, 0x36, 0x28, 0x28, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x3a, 0x28, 0x24,
                     0x26, 0x00, 0x3d, 0x00, 0x3a, 0x39, 0x00, 0x27, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x21, 0x25,
                     0x00, 0x1a, 0x00, 0x00, 0x24, 0x25, 0x26, 0x11, 0x11, 0x11, 0x11, 0x00, 0x00, 0x00, 0x00, 0x2c,
                     0x28, 0x38, 0x28, 0x28, 0x28, 0x38, 0x31, 0x33, 0x28, 0x00, 0x00, 0x00, 0x17, 0x17, 0x00, 0x00,
                     0x00, 0x2a, 0x00, 0x00, 0x00, 0x00, 0x11, 0x11, 0x00, 0x00, 0x24, 0x26, 0x10, 0x28, 0x29, 0x00,
                     0x28, 0x28, 0x1b, 0x1b, 0x1b, 0x28, 0x28, 0x00, 0x00, 0x00, 0x00, 0x00, 0x2a, 0x21, 0x25, 0x48,
                     0x26, 0x28, 0x39, 0x00, 0x00, 0x00, 0x3b, 0x34, 0x36, 0x2b, 0x00, 0x00, 0x00, 0x00, 0x28, 0x24,
                     0x25, 0x23, 0x28, 0x28, 0x3a, 0x67, 0x00, 0x3a, 0x28, 0x28, 0x28, 0x29, 0x00, 0x2a, 0x31, 0x32,
                     0x25, 0x33, 0x38, 0x28, 0x28, 0x29, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x28, 0x38, 0x24,
                     0x25, 0x23, 0x20, 0x20, 0x10, 0x29, 0x00, 0x30, 0x39, 0x00, 0x00, 0x00, 0x00, 0x58, 0x24, 0x48,
                     0x00, 0x00, 0x00, 0x3a, 0x31, 0x32, 0x32, 0x35, 0x35, 0x35, 0x36, 0x67, 0x58, 0x00, 0x00, 0x3c,
                     0x28, 0x28, 0x28, 0x28, 0x10, 0x28, 0x21, 0x23, 0x29, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
                     0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x34, 0x36, 0x00, 0x3a, 0x24, 0x26, 0x28, 0x28, 0x00, 0x00,
                     0x38, 0x28, 0x39, 0x00, 0x00, 0x00, 0x2a, 0x29, 0x00, 0x00, 0x00, 0x00, 0x00, 0x31, 0x32, 0x32,
                     0x26, 0x10, 0x10, 0x00, 0x00, 0x00, 0x00, 0x28, 0x28, 0x39, 0x00, 0x00, 0x00, 0x00, 0x2a, 0x24,
                     0x25, 0x33, 0x28, 0x28, 0x28, 0x38, 0x00, 0x28, 0x28, 0x28, 0x39, 0x00, 0x00, 0x00, 0x17, 0x00,
                     0x26, 0x00, 0x00, 0x2a, 0x28, 0x00, 0x00, 0x00, 0x00, 0x3a, 0x28, 0x3a, 0x28, 0x28, 0x28, 0x24,
                     0x25, 0x25, 0x22, 0x23, 0x28, 0x39, 0x00, 0x37, 0x28, 0x58, 0x39, 0x00, 0x68, 0x28, 0x31, 0x32,
                     0x00, 0x00, 0x00, 0x28, 0x28, 0x28, 0x28, 0x28, 0x20, 0x20, 0x28, 0x28, 0x28, 0x39, 0x21, 0x22,
                     0x28, 0x29, 0x00, 0x2a, 0x28, 0x28, 0x24, 0x26, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
                     0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x20, 0x38, 0x28, 0x28, 0x31, 0x25, 0x23, 0x00, 0x00, 0x00,
                     0x28, 0x28, 0x28, 0x29, 0x00, 0x00, 0x00, 0x00, 0x00, 0x16, 0x3a, 0x67, 0x68, 0x28, 0x28, 0x00,
                     0x33, 0x38, 0x28, 0x0b, 0x00, 0x00, 0x00, 0x10, 0x38, 0x28, 0x00, 0x00, 0x0b, 0x00, 0x00, 0x31,
                     0x33, 0x28, 0x28, 0x28, 0x28, 0x28, 0x68, 0x28, 0x28, 0x28, 0x28, 0x00, 0x00, 0x00, 0x17, 0x00,
                     0x33, 0x00, 0x00, 0x00, 0x28, 0x67, 0x58, 0x00, 0x00, 0x28, 0x10, 0x28, 0x28, 0x34, 0x22, 0x25,
                     0x25, 0x25, 0x48, 0x26, 0x28, 0x28, 0x67, 0x20, 0x28, 0x28, 0x28, 0x38, 0x28, 0x28, 0x21, 0x22,
                     0x00, 0x00, 0x3a, 0x28, 0x38, 0x28, 0x10, 0x29, 0x00, 0x00, 0x2a, 0x28, 0x38, 0x28, 0x24, 0x25,
                     0x2a, 0x00, 0x00, 0x00, 0x28, 0x38, 0x24, 0x26, 0x00, 0x00, 0x00, 0x17, 0x17, 0x00, 0x00, 0x00,
                     0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x27, 0x28, 0x28, 0x2a, 0x28, 0x31, 0x33, 0x39, 0x00, 0x00,
                     0x28, 0x29, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x2a, 0x28, 0x28, 0x28, 0x29, 0x00,
                     0x2a, 0x28, 0x39, 0x00, 0x00, 0x00, 0x00, 0x2a, 0x28, 0x29, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
                     0x28, 0x28, 0x28, 0x38, 0x28, 0x28, 0x28, 0x28, 0x28, 0x28, 0x29, 0x00, 0x00, 0x00, 0x00, 0x00,
                     0x00, 0x00, 0x00, 0x3a, 0x28, 0x28, 0x38, 0x3e, 0x3a, 0x28, 0x28, 0x28, 0x38, 0x28, 0x24, 0x25,
                     0x48, 0x25, 0x25, 0x26, 0x00, 0x2a, 0x28, 0x27, 0x29, 0x00, 0x2a, 0x28, 0x28, 0x34, 0x32, 0x25,
                     0x00, 0x00, 0x00, 0x2a, 0x28, 0x28, 0x28, 0x00, 0x00, 0x00, 0x00, 0x28, 0x10, 0x28, 0x24, 0x25,
                     0x00, 0x00, 0x00, 0x00, 0x2a, 0x28, 0x24, 0x26, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
                     0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x37, 0x28, 0x00, 0x00, 0x00, 0x2a, 0x28, 0x28, 0x39, 0x00,
                     0x28, 0x00, 0x00, 0x00, 0x39, 0x28, 0x39, 0x00, 0x00, 0x00, 0x00, 0x00, 0x28, 0x28, 0x00, 0x00,
                     0x00, 0x28, 0x29, 0x00, 0x00, 0x00, 0x2a, 0x28, 0x28, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
                     0x2a, 0x28, 0x28, 0x28, 0x28, 0x10, 0x28, 0x28, 0x28, 0x28, 0x67, 0x58, 0x00, 0x00, 0x00, 0x00,
                     0x00, 0x00, 0x00, 0x28, 0x38, 0x28, 0x28, 0x21, 0x23, 0x28, 0x00, 0x00, 0x2a, 0x28, 0x24, 0x25,
                     0x32, 0x32, 0x25, 0x26, 0x00, 0x3a, 0x28, 0x30, 0x00, 0x00, 0x00, 0x00, 0x2a, 0x28, 0x28, 0x24,
                     0x00, 0x00, 0x00, 0x00, 0x00, 0x2a, 0x28, 0x11, 0x11, 0x11, 0x11, 0x28, 0x28, 0x28, 0x24, 0x48,
                     0x00, 0x00, 0x00, 0x3a, 0x28, 0x28, 0x31, 0x33, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x17, 0x17,
                     0x00, 0x01, 0x3f, 0x00, 0x00, 0x00, 0x20, 0x29, 0x00, 0x00, 0x00, 0x00, 0x38, 0x28, 0x00, 0x00,
                     0x28, 0x01, 0x3a, 0x28, 0x28, 0x10, 0x28, 0x58, 0x00, 0x00, 0x00, 0x3a, 0x28, 0x29, 0x00, 0x00,
                     0x00, 0x2a, 0x28, 0x0c, 0x00, 0x00, 0x00, 0x3a, 0x38, 0x0c, 0x00, 0x00, 0x00, 0x00, 0x00, 0x0c,
                     0x00, 0x00, 0x2a, 0x28, 0x28, 0x28, 0x28, 0x28, 0x29, 0x28, 0x28, 0x29, 0x00, 0x00, 0x00, 0x3a,
                     0x00, 0x01, 0x3a, 0x21, 0x23, 0x28, 0x2a, 0x31, 0x33, 0x29, 0x00, 0x11, 0x11, 0x11, 0x24, 0x25,
                     0x00, 0x28, 0x31, 0x26, 0x3a, 0x38, 0x29, 0x30, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x2a, 0x31,
                     0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x28, 0x34, 0x22, 0x22, 0x36, 0x29, 0x2a, 0x00, 0x24, 0x25,
                     0x3e, 0x01, 0x3a, 0x38, 0x28, 0x29, 0x2a, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
                     0x35, 0x35, 0x35, 0x36, 0x00, 0x00, 0x20, 0x00, 0x00, 0x00, 0x00, 0x3d, 0x2a, 0x28, 0x67, 0x14,
                     0x22, 0x22, 0x23, 0x28, 0x28, 0x28, 0x28, 0x28, 0x39, 0x00, 0x58, 0x28, 0x38, 0x28, 0x3d, 0x00,
                     0x00, 0x3a, 0x29, 0x00, 0x00, 0x00, 0x00, 0x28, 0x28, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
                     0x00, 0x00, 0x2a, 0x28, 0x28, 0x2a, 0x29, 0x00, 0x00, 0x58, 0x10, 0x00, 0x12, 0x00, 0x2a, 0x28,
                     0x22, 0x22, 0x22, 0x25, 0x26, 0x29, 0x00, 0x21, 0x23, 0x11, 0x11, 0x21, 0x22, 0x22, 0x25, 0x25,
                     0x00, 0x2a, 0x38, 0x37, 0x28, 0x29, 0x00, 0x30, 0x11, 0x11, 0x11, 0x00, 0x00, 0x00, 0x3a, 0x28,
                     0x00, 0x01, 0x3f, 0x00, 0x00, 0x00, 0x2a, 0x28, 0x24, 0x26, 0x29, 0x00, 0x00, 0x00, 0x24, 0x25,
                     0x22, 0x22, 0x22, 0x23, 0x29, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x17, 0x17, 0x00, 0x00,
                     0x2a, 0x28, 0x20, 0x39, 0x00, 0x3a, 0x20, 0x00, 0x00, 0x3a, 0x00, 0x34, 0x35, 0x35, 0x35, 0x35,
                     0x25, 0x25, 0x25, 0x22, 0x22, 0x22, 0x23, 0x28, 0x28, 0x28, 0x28, 0x10, 0x28, 0x28, 0x21, 0x22,
                     0x0b, 0x10, 0x00, 0x00, 0x00, 0x00, 0x0b, 0x28, 0x10, 0x00, 0x00, 0x00, 0x0b, 0x00, 0x00, 0x00,
                     0x2c, 0x00, 0x00, 0x28, 0x38, 0x00, 0x00, 0x00, 0x00, 0x2a, 0x28, 0x39, 0x17, 0x00, 0x00, 0x28,
                     0x25, 0x48, 0x25, 0x25, 0x26, 0x11, 0x11, 0x24, 0x25, 0x22, 0x22, 0x25, 0x25, 0x25, 0x48, 0x25,
                     0x00, 0x01, 0x2a, 0x28, 0x28, 0x67, 0x3f, 0x24, 0x22, 0x22, 0x23, 0x00, 0x00, 0x00, 0x38, 0x28,
                     0x22, 0x22, 0x23, 0x00, 0x00, 0x12, 0x00, 0x2a, 0x24, 0x26, 0x00, 0x00, 0x00, 0x12, 0x24, 0x25,
                     0x25, 0x25, 0x25, 0x26, 0x00, 0x00, 0x00, 0x00, 0x17, 0x17, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
                     0x00, 0x38, 0x20, 0x28, 0x39, 0x28, 0x27, 0x08, 0x00, 0x28, 0x67, 0x68, 0x20, 0x28, 0x28, 0x28,
                     0x25, 0x48, 0x25, 0x25, 0x25, 0x25, 0x26, 0x2a, 0x28, 0x28, 0x21, 0x22, 0x22, 0x22, 0x25, 0x25,
                     0x3a, 0x28, 0x01, 0x3d, 0x00, 0x00, 0x00, 0x68, 0x28, 0x39, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
                     0x3c, 0x01, 0x68, 0x28, 0x28, 0x00, 0x17, 0x17, 0x17, 0x00, 0x3a, 0x28, 0x00, 0x00, 0x3a, 0x28,
                     0x25, 0x25, 0x25, 0x25, 0x25, 0x22, 0x22, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25,
                     0x22, 0x22, 0x22, 0x22, 0x22, 0x22, 0x22, 0x25, 0x25, 0x48, 0x26, 0x67, 0x58, 0x68, 0x28, 0x28,
                     0x25, 0x48, 0x26, 0x00, 0x00, 0x27, 0x00, 0x00, 0x24, 0x26, 0x00, 0x00, 0x00, 0x21, 0x25, 0x25,
                     0x25, 0x25, 0x48, 0x26, 0x17, 0x17, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
                     0x00, 0x2a, 0x20, 0x28, 0x10, 0x28, 0x30, 0x00, 0x3a, 0x28, 0x28, 0x28, 0x20, 0x28, 0x28, 0x28,
                     0x25, 0x25, 0x25, 0x25, 0x48, 0x25, 0x26, 0x00, 0x00, 0x2a, 0x24, 0x25, 0x25, 0x25, 0x48, 0x25,
                     0x28, 0x21, 0x22, 0x23, 0x00, 0x00, 0x00, 0x28, 0x28, 0x28, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
                     0x22, 0x22, 0x22, 0x23, 0x28, 0x67, 0x00, 0x00, 0x00, 0x00, 0x28, 0x28, 0x39, 0x00, 0x28, 0x38,
                     0x25, 0x32, 0x33, 0x00, 0x00, 0x00, 0x24, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x25, 0x25,
                     0x25, 0x25, 0x26, 0x28, 0x28, 0x28, 0x28, 0x24, 0x25, 0x32, 0x32, 0x32, 0x32, 0x25, 0x48, 0x25,
                     0x25, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x25, 0x26, 0x28, 0x28, 0x28, 0x24, 0x48, 0x25,
                     0x25, 0x25, 0x25, 0x33, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x52,
                     0x25, 0x25, 0x32, 0x32, 0x32, 0x32, 0x33, 0x31, 0x32, 0x32, 0x32, 0x32, 0x33, 0x28, 0x29, 0x00,
                     0x26, 0x28, 0x29, 0x28, 0x67, 0x00, 0x00, 0x00, 0x00, 0x00, 0x28, 0x28, 0x31, 0x32, 0x32, 0x32,
                     0x25, 0x25, 0x25, 0x32, 0x33, 0x28, 0x28, 0x00, 0x31, 0x25, 0x25, 0x48, 0x25, 0x25, 0x25, 0x48,
                     0x25, 0x25, 0x48, 0x26, 0x28, 0x38, 0x28, 0x31, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x25, 0x48,
                     0x26, 0x28, 0x28, 0x00, 0x00, 0x00, 0x30, 0x40, 0x2a, 0x28, 0x28, 0x28, 0x28, 0x28, 0x24, 0x25,
                     0x25, 0x48, 0x26, 0x28, 0x38, 0x28, 0x28, 0x31, 0x33, 0x38, 0x28, 0x29, 0x00, 0x31, 0x32, 0x25,
                     0x26, 0x28, 0x00, 0x00, 0x16, 0x3a, 0x28, 0x28, 0x31, 0x33, 0x28, 0x28, 0x38, 0x24, 0x25, 0x25,
                     0x48, 0x25, 0x26, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x52,
                     0x25, 0x26, 0x00, 0x00, 0x16, 0x00, 0x00, 0x00, 0x00, 0x2a, 0x10, 0x28, 0x28, 0x38, 0x39, 0x00,
                     0x26, 0x28, 0x1a, 0x38, 0x20, 0x39, 0x3d, 0x00, 0x00, 0x00, 0x00, 0x2a, 0x38, 0x28, 0x28, 0x28,
                     0x25, 0x25, 0x26, 0x28, 0x28, 0x28, 0x29, 0x00, 0x3b, 0x24, 0x25, 0x32, 0x32, 0x32, 0x32, 0x32,
                     0x32, 0x32, 0x32, 0x33, 0x28, 0x28, 0x28, 0x28, 0x28, 0x28, 0x10, 0x28, 0x28, 0x20, 0x31, 0x25,
                     0x33, 0x28, 0x39, 0x00, 0x00, 0x00, 0x37, 0x00, 0x00, 0x2a, 0x38, 0x28, 0x00, 0x2a, 0x24, 0x25,
                     0x25, 0x25, 0x26, 0x28, 0x28, 0x28, 0x28, 0x20, 0x28, 0x29, 0x2a, 0x00, 0x00, 0x00, 0x2a, 0x31,
                     0x33, 0x28, 0x11, 0x11, 0x11, 0x28, 0x28, 0x28, 0x00, 0x00, 0x28, 0x00, 0x2a, 0x31, 0x25, 0x25,
                     0x25, 0x25, 0x26, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x52,
                     0x25, 0x26, 0x00, 0x00, 0x00, 0x00, 0x11, 0x11, 0x00, 0x00, 0x00, 0x29, 0x2a, 0x28, 0x29, 0x00,
                     0x26, 0x28, 0x3a, 0x28, 0x20, 0x10, 0x20, 0x11, 0x11, 0x11, 0x21, 0x22, 0x23, 0x28, 0x28, 0x10,
                     0x25, 0x25, 0x26, 0x28, 0x38, 0x28, 0x00, 0x00, 0x3b, 0x24, 0x26, 0x2b, 0x00, 0x2a, 0x2a, 0x38,
                     0x28, 0x28, 0x28, 0x28, 0x28, 0x29, 0x00, 0x2a, 0x28, 0x00, 0x28, 0x28, 0x38, 0x28, 0x28, 0x31,
                     0x28, 0x28, 0x10, 0x29, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x28, 0x28, 0x39, 0x00, 0x24, 0x48,
                     0x25, 0x25, 0x26, 0x28, 0x29, 0x00, 0x28, 0x20, 0x67, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
                     0x38, 0x10, 0x21, 0x22, 0x23, 0x28, 0x38, 0x29, 0x00, 0x3a, 0x10, 0x29, 0x00, 0x2a, 0x24, 0x25,
                     0x32, 0x32, 0x33, 0x67, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x42, 0x00,
                     0x25, 0x26, 0x39, 0x00, 0x00, 0x00, 0x21, 0x23, 0x00, 0x00, 0x00, 0x00, 0x00, 0x21, 0x22, 0x22,
                     0x25, 0x22, 0x22, 0x23, 0x21, 0x22, 0x23, 0x21, 0x22, 0x23, 0x24, 0x48, 0x26, 0x28, 0x28, 0x28,
                     0x32, 0x32, 0x33, 0x28, 0x28, 0x28, 0x00, 0x00, 0x3b, 0x31, 0x33, 0x2b, 0x00, 0x00, 0x00, 0x28,
                     0x10, 0x28, 0x29, 0x00, 0x00, 0x00, 0x00, 0x00, 0x29, 0x00, 0x2a, 0x28, 0x28, 0x28, 0x29, 0x00,
                     0x28, 0x28, 0x28, 0x00, 0x16, 0x00, 0x00, 0x00, 0x16, 0x2a, 0x28, 0x28, 0x28, 0x00, 0x24, 0x25,
                     0x25, 0x25, 0x26, 0x27, 0x00, 0x00, 0x2a, 0x20, 0x29, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
                     0x28, 0x34, 0x25, 0x25, 0x33, 0x29, 0x2a, 0x00, 0x00, 0x00, 0x2a, 0x00, 0x11, 0x11, 0x24, 0x25,
                     0x22, 0x23, 0x28, 0x28, 0x00, 0x00, 0x2c, 0x46, 0x47, 0x2c, 0x00, 0x00, 0x00, 0x42, 0x53, 0x53,
                     0x25, 0x26, 0x28, 0x00, 0x00, 0x3a, 0x24, 0x26, 0x00, 0x00, 0x16, 0x00, 0x00, 0x24, 0x25, 0x25,
                     0x25, 0x25, 0x48, 0x26, 0x31, 0x32, 0x33, 0x31, 0x32, 0x33, 0x24, 0x25, 0x26, 0x20, 0x28, 0x38,
                     0x22, 0x22, 0x23, 0x28, 0x29, 0x28, 0x67, 0x00, 0x00, 0x28, 0x29, 0x00, 0x00, 0x00, 0x00, 0x00,
                     0x28, 0x38, 0x00, 0x11, 0x11, 0x00, 0x00, 0x12, 0x00, 0x00, 0x00, 0x28, 0x29, 0x2a, 0x16, 0x00,
                     0x28, 0x38, 0x28, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x3a, 0x28, 0x29, 0x00, 0x24, 0x25,
                     0x48, 0x25, 0x26, 0x37, 0x00, 0x00, 0x00, 0x29, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x3a,
                     0x29, 0x3b, 0x24, 0x26, 0x28, 0x39, 0x00, 0x00, 0x00, 0x00, 0x00, 0x3b, 0x21, 0x22, 0x25, 0x25,
                     0x25, 0x26, 0x38, 0x28, 0x67, 0x00, 0x3c, 0x56, 0x57, 0x3c, 0x42, 0x43, 0x43, 0x53, 0x63, 0x63,
                     0x32, 0x33, 0x28, 0x39, 0x00, 0x28, 0x24, 0x26, 0x11, 0x11, 0x11, 0x11, 0x11, 0x24, 0x25, 0x25,
                     0x25, 0x48, 0x25, 0x26, 0x20, 0x1b, 0x1b, 0x1b, 0x1b, 0x1b, 0x24, 0x25, 0x26, 0x28, 0x28, 0x28,
                     0x25, 0x25, 0x26, 0x00, 0x00, 0x2a, 0x28, 0x14, 0x3a, 0x29, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
                     0x28, 0x29, 0x3b, 0x21, 0x23, 0x00, 0x00, 0x17, 0x00, 0x00, 0x11, 0x28, 0x67, 0x00, 0x00, 0x00,
                     0x28, 0x28, 0x28, 0x67, 0x58, 0x00, 0x00, 0x00, 0x58, 0x68, 0x28, 0x38, 0x00, 0x00, 0x31, 0x32,
                     0x32, 0x32, 0x33, 0x20, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x27, 0x28, 0x28,
                     0x00, 0x3b, 0x24, 0x26, 0x29, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x3b, 0x31, 0x25, 0x48, 0x25,
                     0x25, 0x33, 0x28, 0x28, 0x28, 0x39, 0x21, 0x22, 0x22, 0x23, 0x52, 0x53, 0x53, 0x64, 0x00, 0x00,
                     0x29, 0x00, 0x2a, 0x28, 0x38, 0x28, 0x31, 0x32, 0x35, 0x35, 0x35, 0x35, 0x22, 0x25, 0x48, 0x25,
                     0x25, 0x25, 0x25, 0x25, 0x23, 0x00, 0x00, 0x00, 0x00, 0x00, 0x31, 0x32, 0x33, 0x28, 0x10, 0x28,
                     0x48, 0x25, 0x26, 0x11, 0x11, 0x11, 0x34, 0x35, 0x36, 0x11, 0x11, 0x11, 0x11, 0x00, 0x00, 0x00,
                     0x00, 0x00, 0x3b, 0x31, 0x33, 0x11, 0x11, 0x11, 0x11, 0x11, 0x27, 0x28, 0x29, 0x00, 0x00, 0x3b,
                     0x28, 0x28, 0x28, 0x28, 0x10, 0x29, 0x00, 0x00, 0x00, 0x2a, 0x28, 0x28, 0x67, 0x00, 0x00, 0x28,
                     0x35, 0x35, 0x35, 0x36, 0x11, 0x11, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x11, 0x30, 0x28, 0x38,
                     0x00, 0x3b, 0x31, 0x33, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x2a, 0x28, 0x31, 0x32, 0x25,
                     0x26, 0x2a, 0x28, 0x28, 0x10, 0x28, 0x24, 0x25, 0x25, 0x26, 0x62, 0x63, 0x64, 0x00, 0x00, 0x00,
                     0x00, 0x16, 0x00, 0x28, 0x28, 0x28, 0x29, 0x00, 0x00, 0x00, 0x00, 0x00, 0x31, 0x32, 0x25, 0x25,
                     0x25, 0x25, 0x25, 0x25, 0x26, 0x67, 0x58, 0x00, 0x00, 0x00, 0x20, 0x00, 0x00, 0x2a, 0x28, 0x28,
                     0x25, 0x25, 0x32, 0x35, 0x35, 0x35, 0x22, 0x22, 0x22, 0x22, 0x22, 0x35, 0x36, 0x39, 0x00, 0x00,
                     0x00, 0x00, 0x3b, 0x34, 0x35, 0x35, 0x35, 0x35, 0x35, 0x36, 0x30, 0x38, 0x00, 0x00, 0x00, 0x17,
                     0x28, 0x29, 0x00, 0x00, 0x2a, 0x00, 0x00, 0x00, 0x00, 0x00, 0x38, 0x2a, 0x29, 0x00, 0x3a, 0x28,
                     0x28, 0x28, 0x28, 0x34, 0x36, 0x20, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x20, 0x30, 0x28, 0x28,
                     0x00, 0x00, 0x2a, 0x29, 0x00, 0x00, 0x11, 0x11, 0x00, 0x00, 0x00, 0x00, 0x28, 0x28, 0x28, 0x31,
                     0x26, 0x00, 0x29, 0x00, 0x2a, 0x28, 0x24, 0x48, 0x25, 0x25, 0x23, 0x00, 0x00, 0x00, 0x00, 0x00,
                     0x39, 0x00, 0x3a, 0x28, 0x29, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x28, 0x31, 0x32,
                     0x25, 0x25, 0x48, 0x25, 0x26, 0x38, 0x29, 0x00, 0x00, 0x00, 0x17, 0x00, 0x00, 0x58, 0x68, 0x28,
                     0x32, 0x33, 0x10, 0x28, 0x29, 0x3b, 0x24, 0x48, 0x25, 0x25, 0x26, 0x28, 0x28, 0x28, 0x00, 0x00,
                     0x00, 0x00, 0x3b, 0x20, 0x1b, 0x1b, 0x1b, 0x1b, 0x1b, 0x1b, 0x30, 0x28, 0x00, 0x00, 0x00, 0x17,
                     0x28, 0x3a, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x28, 0x00, 0x00, 0x00, 0x28, 0x28,
                     0x28, 0x38, 0x10, 0x29, 0x2a, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x2a, 0x37, 0x10, 0x28,
                     0x11, 0x11, 0x11, 0x11, 0x11, 0x11, 0x21, 0x36, 0x00, 0x00, 0x00, 0x00, 0x2a, 0x28, 0x38, 0x0b,
                     0x26, 0x00, 0x00, 0x00, 0x00, 0x21, 0x25, 0x25, 0x25, 0x25, 0x26, 0x00, 0x1c, 0x00, 0x00, 0x00,
                     0x28, 0x28, 0x28, 0x10, 0x00, 0x00, 0x00, 0x00, 0x00, 0x11, 0x00, 0x00, 0x2a, 0x38, 0x28, 0x29,
                     0x25, 0x25, 0x25, 0x25, 0x26, 0x28, 0x00, 0x00, 0x00, 0x00, 0x17, 0x00, 0x00, 0x2a, 0x21, 0x22,
                     0x28, 0x28, 0x29, 0x08, 0x00, 0x3b, 0x24, 0x25, 0x25, 0x48, 0x26, 0x28, 0x28, 0x29, 0x12, 0x00,
                     0x00, 0x00, 0x00, 0x1b, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x30, 0x29, 0x00, 0x00, 0x00, 0x3b,
                     0x38, 0x29, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x3a, 0x10, 0x29, 0x00, 0x00, 0x28, 0x38,
                     0x28, 0x28, 0x28, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x2a, 0x28, 0x28,
                     0x22, 0x35, 0x35, 0x35, 0x35, 0x35, 0x33, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x28, 0x28, 0x39,
                     0x33, 0x00, 0x00, 0x00, 0x00, 0x31, 0x32, 0x25, 0x25, 0x25, 0x33, 0x00, 0x00, 0x00, 0x00, 0x00,
                     0x28, 0x38, 0x28, 0x29, 0x00, 0x00, 0x00, 0x00, 0x3b, 0x20, 0x2b, 0x00, 0x68, 0x28, 0x28, 0x00,
                     0x32, 0x32, 0x32, 0x32, 0x33, 0x29, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x31, 0x25,
                     0x28, 0x28, 0x00, 0x00, 0x00, 0x3b, 0x31, 0x32, 0x32, 0x25, 0x26, 0x38, 0x28, 0x00, 0x17, 0x00,
                     0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x11, 0x00, 0x00, 0x37, 0x00, 0x00, 0x00, 0x00, 0x00,
                     0x29, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x2a, 0x00, 0x00, 0x00, 0x28, 0x29,
                     0x28, 0x29, 0x2a, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x28, 0x2a,
                     0x33, 0x28, 0x38, 0x28, 0x28, 0x29, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x10, 0x28, 0x28,
                     0x00, 0x00, 0x00, 0x00, 0x42, 0x43, 0x44, 0x24, 0x25, 0x26, 0x28, 0x39, 0x00, 0x00, 0x00, 0x00,
                     0x28, 0x00, 0x2a, 0x00, 0x00, 0x11, 0x00, 0x00, 0x00, 0x1b, 0x00, 0x2a, 0x20, 0x10, 0x29, 0x2c,
                     0x1b, 0x1b, 0x1b, 0x1b, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x10, 0x31,
                     0x28, 0x29, 0x16, 0x00, 0x00, 0x00, 0x1b, 0x1b, 0x1b, 0x31, 0x33, 0x28, 0x10, 0x67, 0x00, 0x00,
                     0x00, 0x00, 0x00, 0x11, 0x00, 0x00, 0x3a, 0x27, 0x00, 0x00, 0x1b, 0x00, 0x00, 0x00, 0x00, 0x00,
                     0x00, 0x00, 0x01, 0x00, 0x00, 0x00, 0x11, 0x11, 0x11, 0x00, 0x00, 0x00, 0x00, 0x00, 0x2a, 0x3a,
                     0x2a, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x2a, 0x28, 0x00,
                     0x28, 0x28, 0x29, 0x00, 0x2a, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x28, 0x28, 0x28,
                     0x00, 0x00, 0x00, 0x00, 0x52, 0x53, 0x54, 0x24, 0x48, 0x26, 0x28, 0x28, 0x00, 0x00, 0x00, 0x00,
                     0x29, 0x00, 0x00, 0x00, 0x3b, 0x20, 0x2b, 0x39, 0x00, 0x00, 0x00, 0x00, 0x29, 0x00, 0x00, 0x3c,
                     0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x28, 0x28,
                     0x28, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x1b, 0x1b, 0x2a, 0x28, 0x29, 0x00, 0x00,
                     0x01, 0x00, 0x00, 0x27, 0x39, 0x00, 0x38, 0x30, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
                     0x11, 0x11, 0x20, 0x11, 0x11, 0x11, 0x21, 0x22, 0x23, 0x00, 0x00, 0x00, 0x12, 0x12, 0x00, 0x2a,
                     0x00, 0x01, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x29, 0x00,
                     0x29, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x2a, 0x67, 0x68, 0x28, 0x29, 0x00,
                     0x00, 0x3f, 0x01, 0x00, 0x52, 0x53, 0x54, 0x24, 0x25, 0x26, 0x28, 0x10, 0x67, 0x3a, 0x39, 0x00,
                     0x01, 0x3f, 0x00, 0x00, 0x00, 0x2a, 0x38, 0x29, 0x00, 0x11, 0x00, 0x00, 0x00, 0x00, 0x00, 0x21,
                     0x01, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x3a, 0x67, 0x00, 0x00, 0x00, 0x00, 0x2a, 0x38,
                     0x28, 0x67, 0x58, 0x68, 0x00, 0x00, 0x01, 0x00, 0x00, 0x00, 0x00, 0x68, 0x28, 0x00, 0x00, 0x00,
                     0x21, 0x23, 0x00, 0x37, 0x28, 0x29, 0x28, 0x30, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
                     0x22, 0x22, 0x22, 0x22, 0x22, 0x23, 0x24, 0x48, 0x26, 0x11, 0x11, 0x11, 0x20, 0x20, 0x11, 0x11,
                     0x00, 0x27, 0x39, 0x00, 0x00, 0x17, 0x17, 0x00, 0x00, 0x00, 0x17, 0x17, 0x00, 0x00, 0x00, 0x00,
                     0x00, 0x01, 0x00, 0x00, 0x00, 0x00, 0x17, 0x17, 0x00, 0x00, 0x00, 0x28, 0x28, 0x38, 0x39, 0x3a,
                     0x00, 0x21, 0x22, 0x23, 0x52, 0x53, 0x54, 0x24, 0x25, 0x33, 0x28, 0x28, 0x28, 0x38, 0x29, 0x00,
                     0x22, 0x23, 0x2b, 0x00, 0x00, 0x08, 0x28, 0x39, 0x3b, 0x27, 0x00, 0x00, 0x00, 0x00, 0x14, 0x24,
                     0x23, 0x00, 0x00, 0x00, 0x12, 0x00, 0x00, 0x00, 0x28, 0x29, 0x00, 0x00, 0x00, 0x00, 0x00, 0x28,
                     0x28, 0x28, 0x10, 0x28, 0x67, 0x00, 0x17, 0x17, 0x17, 0x17, 0x17, 0x28, 0x28, 0x39, 0x00, 0x00,
                     0x31, 0x33, 0x39, 0x27, 0x10, 0x12, 0x28, 0x37, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
                     0x25, 0x48, 0x25, 0x25, 0x25, 0x26, 0x24, 0x25, 0x26, 0x21, 0x22, 0x22, 0x22, 0x22, 0x22, 0x22,
                     0x3a, 0x30, 0x38, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
                     0x00, 0x17, 0x17, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x3a, 0x28, 0x28, 0x28, 0x28, 0x28,
                     0x00, 0x24, 0x25, 0x26, 0x52, 0x53, 0x54, 0x24, 0x26, 0x28, 0x28, 0x28, 0x28, 0x28, 0x28, 0x39,
                     0x25, 0x26, 0x2b, 0x00, 0x00, 0x3a, 0x28, 0x10, 0x3b, 0x30, 0x00, 0x00, 0x00, 0x21, 0x22, 0x25,
                     0x26, 0x00, 0x00, 0x00, 0x27, 0x00, 0x00, 0x3a, 0x28, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x28,
                     0x28, 0x38, 0x28, 0x28, 0x28, 0x39, 0x00, 0x00, 0x00, 0x58, 0x68, 0x28, 0x38, 0x28, 0x00, 0x00,
                     0x22, 0x23, 0x38, 0x30, 0x28, 0x17, 0x28, 0x27, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
                     0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x28, 0x24, 0x25, 0x25, 0x25, 0x25, 0x48, 0x25,
                     0x33, 0x29, 0x00, 0x00, 0x31, 0x32, 0x32, 0x32, 0x25, 0x32, 0x32, 0x32, 0x32, 0x32, 0x25, 0x32,
                     0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x3b, 0x20, 0x00, 0x00, 0x31, 0x32, 0x32, 0x25,
                     0x25, 0x26, 0x00, 0x2a, 0x28, 0x38, 0x24, 0x25, 0x25, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32,
                     0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x2a, 0x10, 0x28, 0x29, 0x00, 0x31, 0x32, 0x32, 0x25,
                     0x63, 0x63, 0x63, 0x64, 0x52, 0x53, 0x53, 0x53, 0x54, 0x55, 0x00, 0x00, 0x00, 0x55, 0x52, 0x53,
                     0x25, 0x48, 0x25, 0x25, 0x26, 0x2b, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x24, 0x25, 0x25, 0x25,
                     0x26, 0x28, 0x28, 0x28, 0x24, 0x25, 0x48, 0x25, 0x25, 0x25, 0x48, 0x25, 0x25, 0x25, 0x25, 0x25,
                     0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x58, 0x68, 0x28, 0x24, 0x48, 0x25, 0x25, 0x25, 0x25, 0x25,
                     0x1b, 0x00, 0x16, 0x00, 0x1b, 0x1b, 0x1b, 0x1b, 0x30, 0x1b, 0x1b, 0x1b, 0x1b, 0x1b, 0x30, 0x1b,
                     0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x11, 0x11, 0x20, 0x00, 0x00, 0x00, 0x2a, 0x28, 0x24,
                     0x25, 0x33, 0x00, 0x00, 0x00, 0x2a, 0x31, 0x32, 0x33, 0x00, 0x00, 0x29, 0x00, 0x00, 0x38, 0x29,
                     0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x11, 0x00, 0x00, 0x2a, 0x00, 0x00, 0x00, 0x2a, 0x28, 0x31,
                     0x00, 0x00, 0x00, 0x00, 0x62, 0x63, 0x63, 0x63, 0x64, 0x55, 0x00, 0x00, 0x00, 0x55, 0x52, 0x53,
                     0x25, 0x25, 0x25, 0x48, 0x26, 0x2b, 0x3a, 0x00, 0x00, 0x00, 0x00, 0x00, 0x24, 0x25, 0x48, 0x25,
                     0x26, 0x28, 0x38, 0x28, 0x31, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x25, 0x25, 0x48, 0x25,
                     0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x2a, 0x10, 0x28, 0x31, 0x32, 0x25, 0x25, 0x48, 0x25, 0x25,
                     0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x37, 0x00, 0x00, 0x00, 0x00, 0x00, 0x37, 0x00,
                     0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x3b, 0x34, 0x35, 0x36, 0x00, 0x14, 0x00, 0x00, 0x10, 0x31,
                     0x26, 0x2b, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x2a, 0x00,
                     0x00, 0x00, 0x00, 0x00, 0x00, 0x3b, 0x20, 0x2b, 0x00, 0x12, 0x00, 0x00, 0x00, 0x00, 0x2a, 0x28,
                     0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x65, 0x00, 0x00, 0x00, 0x55, 0x62, 0x63,
                     0x25, 0x25, 0x25, 0x32, 0x33, 0x2b, 0x28, 0x29, 0x00, 0x11, 0x11, 0x20, 0x24, 0x25, 0x25, 0x25,
                     0x26, 0x10, 0x29, 0x00, 0x28, 0x29, 0x00, 0x00, 0x00, 0x00, 0x2a, 0x28, 0x31, 0x25, 0x25, 0x25,
                     0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x2a, 0x28, 0x28, 0x24, 0x25, 0x25, 0x25, 0x48,
                     0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x1b, 0x00, 0x00, 0x00, 0x00, 0x00, 0x1b, 0x00,
                     0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x3b, 0x34, 0x35, 0x36, 0x39, 0x00, 0x00, 0x1b,
                     0x26, 0x72, 0x73, 0x73, 0x73, 0x73, 0x73, 0x73, 0x73, 0x73, 0x73, 0x74, 0x11, 0x00, 0x00, 0x16,
                     0x00, 0x00, 0x00, 0x11, 0x00, 0x00, 0x1b, 0x00, 0x3b, 0x20, 0x2b, 0x00, 0x00, 0x00, 0x16, 0x28,
                     0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x65, 0x00, 0x00,
                     0x25, 0x25, 0x33, 0x28, 0x28, 0x28, 0x28, 0x10, 0x3a, 0x21, 0x22, 0x22, 0x25, 0x25, 0x25, 0x25,
                     0x26, 0x28, 0x00, 0x00, 0x2a, 0x00, 0x11, 0x11, 0x11, 0x00, 0x00, 0x28, 0x38, 0x24, 0x25, 0x25,
                     0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x39, 0x3a, 0x28, 0x28, 0x24, 0x25, 0x25, 0x25, 0x25,
                     0x00, 0x00, 0x16, 0x00, 0x00, 0x11, 0x00, 0x00, 0x00, 0x00, 0x00, 0x11, 0x00, 0x00, 0x00, 0x00,
                     0x11, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x20, 0x10, 0x28, 0x00, 0x11,
                     0x25, 0x22, 0x22, 0x22, 0x22, 0x22, 0x22, 0x22, 0x22, 0x22, 0x22, 0x22, 0x23, 0x2b, 0x00, 0x00,
                     0x00, 0x00, 0x3b, 0x20, 0x2b, 0x00, 0x00, 0x00, 0x00, 0x1b, 0x00, 0x00, 0x00, 0x00, 0x00, 0x2a,
                     0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x39, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
                     0x48, 0x26, 0x28, 0x28, 0x28, 0x38, 0x28, 0x28, 0x28, 0x31, 0x32, 0x32, 0x25, 0x48, 0x25, 0x25,
                     0x26, 0x29, 0x00, 0x00, 0x00, 0x11, 0x42, 0x43, 0x44, 0x00, 0x00, 0x2a, 0x28, 0x24, 0x25, 0x48,
                     0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x2a, 0x28, 0x38, 0x28, 0x24, 0x48, 0x25, 0x25, 0x25,
                     0x00, 0x00, 0x00, 0x00, 0x3b, 0x20, 0x2b, 0x39, 0x16, 0x00, 0x3b, 0x20, 0x2b, 0x00, 0x16, 0x00,
                     0x27, 0x39, 0x3a, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x1b, 0x2a, 0x28, 0x39, 0x21,
                     0x25, 0x48, 0x25, 0x25, 0x25, 0x25, 0x25, 0x32, 0x32, 0x32, 0x32, 0x32, 0x26, 0x2b, 0x00, 0x00,
                     0x00, 0x00, 0x00, 0x1b, 0x00, 0x00, 0x00, 0x11, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
                     0x00, 0x00, 0x00, 0x00, 0x39, 0x00, 0x00, 0x68, 0x28, 0x00, 0x00, 0x3a, 0x00, 0x00, 0x00, 0x00,
                     0x25, 0x26, 0x28, 0x28, 0x10, 0x2a, 0x00, 0x2a, 0x28, 0x28, 0x29, 0x00, 0x31, 0x32, 0x32, 0x32,
                     0x26, 0x11, 0x11, 0x11, 0x11, 0x42, 0x53, 0x53, 0x54, 0x00, 0x00, 0x3b, 0x21, 0x25, 0x25, 0x25,
                     0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x28, 0x28, 0x28, 0x31, 0x32, 0x32, 0x32, 0x32,
                     0x28, 0x00, 0x00, 0x3a, 0x00, 0x1b, 0x3a, 0x28, 0x39, 0x00, 0x00, 0x1b, 0x00, 0x00, 0x00, 0x00,
                     0x37, 0x28, 0x38, 0x39, 0x11, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x11, 0x3a, 0x28, 0x28, 0x31,
                     0x32, 0x32, 0x32, 0x32, 0x25, 0x48, 0x26, 0x28, 0x29, 0x00, 0x2a, 0x10, 0x37, 0x2b, 0x00, 0x16,
                     0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x3b, 0x20, 0x2b, 0x00, 0x00, 0x16, 0x00, 0x00, 0x00, 0x00,
                     0x00, 0x00, 0x3a, 0x58, 0x28, 0x28, 0x68, 0x28, 0x28, 0x28, 0x28, 0x28, 0x39, 0x00, 0x00, 0x00,
                     0x25, 0x26, 0x38, 0x28, 0x29, 0x00, 0x00, 0x00, 0x00, 0x2a, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
                     0x25, 0x22, 0x22, 0x22, 0x23, 0x62, 0x63, 0x63, 0x64, 0x00, 0x00, 0x3b, 0x24, 0x25, 0x25, 0x25,
                     0x00, 0x00, 0x00, 0x11, 0x11, 0x11, 0x11, 0x3a, 0x28, 0x28, 0x10, 0x1b, 0x1b, 0x1b, 0x1b, 0x1b,
                     0x28, 0x39, 0x28, 0x28, 0x39, 0x00, 0x28, 0x28, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
                     0x1b, 0x00, 0x2a, 0x28, 0x27, 0x11, 0x00, 0x00, 0x00, 0x00, 0x3b, 0x27, 0x28, 0x28, 0x38, 0x1b,
                     0x22, 0x22, 0x22, 0x23, 0x31, 0x32, 0x33, 0x16, 0x00, 0x00, 0x68, 0x29, 0x00, 0x00, 0x00, 0x00,
                     0x00, 0x01, 0x00, 0x00, 0x00, 0x00, 0x00, 0x1b, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
                     0x68, 0x39, 0x28, 0x28, 0x28, 0x28, 0x10, 0x29, 0x00, 0x00, 0x2a, 0x10, 0x28, 0x3a, 0x67, 0x68,
                     0x25, 0x26, 0x28, 0x28, 0x39, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
                     0x25, 0x25, 0x48, 0x25, 0x25, 0x23, 0x28, 0x38, 0x29, 0x00, 0x00, 0x3b, 0x24, 0x48, 0x25, 0x25,
                     0x00, 0x00, 0x68, 0x21, 0x22, 0x22, 0x23, 0x28, 0x38, 0x28, 0x28, 0x39, 0x00, 0x00, 0x00, 0x00,
                     0x28, 0x28, 0x28, 0x28, 0x28, 0x38, 0x28, 0x29, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x16, 0x00,
                     0x11, 0x00, 0x3a, 0x28, 0x37, 0x27, 0x00, 0x00, 0x00, 0x00, 0x3b, 0x37, 0x2a, 0x28, 0x29, 0x11,
                     0x25, 0x25, 0x48, 0x26, 0x38, 0x28, 0x2a, 0x00, 0x00, 0x00, 0x2a, 0x00, 0x00, 0x00, 0x00, 0x00,
                     0x00, 0x20, 0x11, 0x11, 0x11, 0x11, 0x11, 0x11, 0x11, 0x11, 0x11, 0x11, 0x11, 0x11, 0x00, 0x16,
                     0x28, 0x28, 0x28, 0x2a, 0x38, 0x28, 0x28, 0x00, 0x00, 0x00, 0x00, 0x00, 0x28, 0x28, 0x28, 0x28,
                     0x25, 0x26, 0x28, 0x29, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
                     0x25, 0x25, 0x25, 0x25, 0x25, 0x26, 0x10, 0x2a, 0x00, 0x00, 0x00, 0x3b, 0x24, 0x25, 0x25, 0x25,
                     0x00, 0x00, 0x10, 0x31, 0x32, 0x25, 0x25, 0x22, 0x35, 0x35, 0x35, 0x36, 0x00, 0x00, 0x00, 0x00,
                     0x28, 0x38, 0x00, 0x2a, 0x28, 0x28, 0x28, 0x10, 0x39, 0x39, 0x00, 0x00, 0x11, 0x00, 0x00, 0x00,
                     0x27, 0x28, 0x28, 0x29, 0x1b, 0x30, 0x39, 0x00, 0x00, 0x00, 0x00, 0x1b, 0x00, 0x2a, 0x28, 0x21,
                     0x25, 0x32, 0x25, 0x26, 0x29, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x3a, 0x00, 0x00, 0x00, 0x00,
                     0x00, 0x34, 0x35, 0x35, 0x35, 0x35, 0x35, 0x35, 0x35, 0x35, 0x35, 0x35, 0x35, 0x36, 0x2b, 0x00,
                     0x28, 0x28, 0x29, 0x00, 0x28, 0x28, 0x29, 0x00, 0x60, 0x61, 0x00, 0x3a, 0x28, 0x38, 0x28, 0x2a,
                     0x48, 0x26, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
                     0x25, 0x48, 0x25, 0x25, 0x25, 0x26, 0x29, 0x00, 0x00, 0x11, 0x11, 0x11, 0x24, 0x25, 0x25, 0x25,
                     0x00, 0x00, 0x2a, 0x28, 0x28, 0x31, 0x32, 0x26, 0x1b, 0x1b, 0x1b, 0x1b, 0x00, 0x00, 0x00, 0x00,
                     0x29, 0x00, 0x00, 0x00, 0x00, 0x2a, 0x28, 0x28, 0x28, 0x28, 0x39, 0x3b, 0x27, 0x2b, 0x00, 0x00,
                     0x37, 0x28, 0x10, 0x00, 0x11, 0x30, 0x28, 0x3a, 0x00, 0x00, 0x00, 0x11, 0x00, 0x28, 0x28, 0x31,
                     0x26, 0x01, 0x31, 0x33, 0x16, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x28, 0x39, 0x00, 0x00, 0x00,
                     0x00, 0x20, 0x28, 0x38, 0x28, 0x28, 0x28, 0x20, 0x28, 0x28, 0x28, 0x28, 0x28, 0x27, 0x2b, 0x00,
                     0x38, 0x28, 0x00, 0x00, 0x2a, 0x28, 0x3d, 0x00, 0x70, 0x71, 0x3f, 0x28, 0x28, 0x29, 0x00, 0x00,
                     0x25, 0x26, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x39, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
                     0x25, 0x25, 0x25, 0x25, 0x48, 0x26, 0x00, 0x00, 0x3b, 0x21, 0x22, 0x23, 0x31, 0x25, 0x48, 0x25,
                     0x00, 0x00, 0x00, 0x28, 0x38, 0x29, 0x3b, 0x30, 0x00, 0x00, 0x00, 0x00, 0x00, 0x12, 0x00, 0x00,
                     0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x28, 0x28, 0x28, 0x28, 0x3b, 0x30, 0x2b, 0x00, 0x00,
                     0x1b, 0x2a, 0x28, 0x38, 0x27, 0x30, 0x28, 0x10, 0x39, 0x00, 0x00, 0x27, 0x3a, 0x28, 0x29, 0x1b,
                     0x26, 0x17, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x39, 0x00, 0x00, 0x38, 0x28, 0x00, 0x00, 0x00,
                     0x00, 0x1b, 0x2a, 0x28, 0x28, 0x10, 0x28, 0x1b, 0x2a, 0x28, 0x38, 0x2a, 0x28, 0x37, 0x2b, 0x00,
                     0x28, 0x28, 0x39, 0x00, 0x00, 0x28, 0x21, 0x22, 0x23, 0x21, 0x22, 0x23, 0x28, 0x00, 0x00, 0x3a,
                     0x32, 0x33, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x28, 0x29, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
                     0x32, 0x32, 0x32, 0x32, 0x32, 0x33, 0x00, 0x00, 0x3b, 0x24, 0x25, 0x25, 0x23, 0x31, 0x25, 0x25,
                     0x00, 0x00, 0x00, 0x2a, 0x28, 0x00, 0x3b, 0x37, 0x00, 0x00, 0x00, 0x00, 0x3a, 0x27, 0x00, 0x00,
                     0x00, 0x01, 0x00, 0x00, 0x00, 0x11, 0x11, 0x11, 0x11, 0x28, 0x38, 0x3b, 0x37, 0x2b, 0x00, 0x3a,
                     0x00, 0x00, 0x28, 0x28, 0x37, 0x30, 0x29, 0x00, 0x28, 0x38, 0x00, 0x37, 0x28, 0x38, 0x00, 0x11,
                     0x26, 0x39, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x28, 0x00, 0x00, 0x28, 0x28, 0x29, 0x00, 0x00,
                     0x00, 0x00, 0x00, 0x29, 0x16, 0x2a, 0x28, 0x00, 0x00, 0x28, 0x16, 0x00, 0x28, 0x28, 0x00, 0x00,
                     0x10, 0x29, 0x00, 0x00, 0x00, 0x20, 0x31, 0x32, 0x33, 0x24, 0x48, 0x26, 0x28, 0x42, 0x43, 0x43,
                     0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x28, 0x00, 0x00, 0x58, 0x68, 0x00, 0x00, 0x00,
                     0x38, 0x28, 0x28, 0x29, 0x00, 0x00, 0x00, 0x00, 0x3b, 0x24, 0x25, 0x48, 0x25, 0x23, 0x31, 0x32,
                     0x00, 0x00, 0x01, 0x00, 0x28, 0x00, 0x00, 0x28, 0x00, 0x00, 0x00, 0x2a, 0x28, 0x30, 0x00, 0x00,
                     0x22, 0x22, 0x23, 0x11, 0x11, 0x21, 0x35, 0x35, 0x36, 0x10, 0x28, 0x28, 0x29, 0x00, 0x00, 0x38,
                     0x00, 0x00, 0x29, 0x00, 0x1b, 0x30, 0x00, 0x00, 0x2a, 0x28, 0x00, 0x00, 0x28, 0x28, 0x00, 0x21,
                     0x26, 0x28, 0x29, 0x00, 0x00, 0x00, 0x00, 0x3a, 0x28, 0x29, 0x00, 0x28, 0x28, 0x00, 0x00, 0x00,
                     0x00, 0x58, 0x68, 0x00, 0x00, 0x28, 0x28, 0x3a, 0x28, 0x28, 0x39, 0x00, 0x28, 0x29, 0x16, 0x00,
                     0x28, 0x00, 0x01, 0x00, 0x00, 0x21, 0x22, 0x22, 0x22, 0x25, 0x25, 0x25, 0x23, 0x52, 0x53, 0x53,
                     0x00, 0x00, 0x00, 0x3f, 0x01, 0x00, 0x00, 0x3a, 0x28, 0x00, 0x00, 0x2a, 0x10, 0x00, 0x00, 0x00,
                     0x28, 0x29, 0x00, 0x00, 0x00, 0x00, 0x39, 0x00, 0x3b, 0x24, 0x25, 0x25, 0x25, 0x25, 0x22, 0x22,
                     0x40, 0x00, 0x21, 0x22, 0x23, 0x2b, 0x00, 0x38, 0x39, 0x12, 0x00, 0x68, 0x38, 0x30, 0x39, 0x00,
                     0x25, 0x48, 0x25, 0x22, 0x22, 0x26, 0x0c, 0x00, 0x2a, 0x28, 0x28, 0x28, 0x00, 0x00, 0x3a, 0x28,
                     0x01, 0x00, 0x00, 0x00, 0x3a, 0x37, 0x08, 0x00, 0x00, 0x28, 0x39, 0x00, 0x28, 0x29, 0x00, 0x31,
                     0x26, 0x28, 0x00, 0x00, 0x00, 0x00, 0x00, 0x28, 0x38, 0x00, 0x3a, 0x28, 0x10, 0x00, 0x00, 0x00,
                     0x00, 0x2a, 0x28, 0x28, 0x28, 0x29, 0x2a, 0x28, 0x28, 0x38, 0x28, 0x28, 0x28, 0x00, 0x00, 0x00,
                     0x43, 0x43, 0x43, 0x43, 0x44, 0x24, 0x25, 0x48, 0x25, 0x25, 0x25, 0x25, 0x26, 0x52, 0x53, 0x53,
                     0x00, 0x00, 0x00, 0x21, 0x36, 0x00, 0x00, 0x38, 0x28, 0x39, 0x00, 0x00, 0x28, 0x00, 0x1c, 0x00,
                     0x28, 0x01, 0x3d, 0x3e, 0x00, 0x3a, 0x28, 0x00, 0x3b, 0x24, 0x25, 0x25, 0x25, 0x48, 0x25, 0x25,
                     0x21, 0x23, 0x24, 0x25, 0x26, 0x2b, 0x68, 0x28, 0x28, 0x27, 0x28, 0x28, 0x10, 0x30, 0x28, 0x00,
                     0x25, 0x25, 0x25, 0x25, 0x48, 0x26, 0x00, 0x00, 0x00, 0x28, 0x28, 0x29, 0x00, 0x00, 0x28, 0x28,
                     0x23, 0x00, 0x00, 0x00, 0x38, 0x28, 0x39, 0x00, 0x00, 0x2a, 0x28, 0x10, 0x28, 0x00, 0x00, 0x1b,
                     0x26, 0x38, 0x39, 0x00, 0x00, 0x00, 0x00, 0x28, 0x28, 0x00, 0x28, 0x28, 0x28, 0x39, 0x00, 0x00,
                     0x00, 0x00, 0x00, 0x38, 0x28, 0x00, 0x00, 0x00, 0x2a, 0x28, 0x10, 0x28, 0x00, 0x00, 0x00, 0x00,
                     0x53, 0x53, 0x53, 0x53, 0x54, 0x24, 0x25, 0x25, 0x25, 0x25, 0x25, 0x48, 0x26, 0x52, 0x53, 0x53,
                     0x00, 0x00, 0x00, 0x30, 0x42, 0x44, 0x00, 0x28, 0x28, 0x28, 0x00, 0x00, 0x28, 0x39, 0x00, 0x00,
                     0x22, 0x22, 0x22, 0x23, 0x10, 0x28, 0x38, 0x39, 0x3b, 0x24, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25,
                     0x25, 0x25, 0x25, 0x25, 0x25, 0x26, 0x2b, 0x1b, 0x1b, 0x1b, 0x31, 0x32, 0x32, 0x25, 0x26, 0x00,
                     0x48, 0x25, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x25, 0x25, 0x32, 0x32, 0x32, 0x33, 0x28, 0x28,
                     0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x48, 0x25, 0x32, 0x33, 0x2b, 0x28,
                     0x32, 0x32, 0x32, 0x32, 0x32, 0x25, 0x26, 0x28, 0x28, 0x00, 0x00, 0x3b, 0x24, 0x25, 0x25, 0x25,
                     0x25, 0x48, 0x25, 0x25, 0x25, 0x25, 0x25, 0x48, 0x48, 0x25, 0x25, 0x25, 0x26, 0x38, 0x28, 0x24,
                     0x25, 0x48, 0x25, 0x25, 0x32, 0x33, 0x28, 0x28, 0x29, 0x24, 0x25, 0x32, 0x32, 0x32, 0x25, 0x25,
                     0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
                     0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
                     0x25, 0x25, 0x25, 0x48, 0x25, 0x26, 0x2b, 0x00, 0x00, 0x00, 0x1b, 0x1b, 0x1b, 0x24, 0x26, 0x00,
                     0x32, 0x33, 0x28, 0x67, 0x00, 0x00, 0x00, 0x28, 0x24, 0x33, 0x2b, 0x2a, 0x28, 0x10, 0x28, 0x38,
                     0x25, 0x25, 0x25, 0x48, 0x25, 0x25, 0x32, 0x32, 0x32, 0x32, 0x25, 0x26, 0x1b, 0x1b, 0x00, 0x38,
                     0x29, 0x01, 0x00, 0x3a, 0x28, 0x24, 0x26, 0x38, 0x29, 0x00, 0x00, 0x3b, 0x24, 0x32, 0x32, 0x32,
                     0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x25, 0x26, 0x10, 0x28, 0x31,
                     0x25, 0x25, 0x32, 0x33, 0x1b, 0x1b, 0x10, 0x28, 0x14, 0x31, 0x33, 0x38, 0x28, 0x28, 0x24, 0x48,
                     0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
                     0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
                     0x25, 0x25, 0x25, 0x25, 0x25, 0x26, 0x2b, 0x00, 0x00, 0x00, 0x00, 0x00, 0x2a, 0x24, 0x26, 0x67,
                     0x28, 0x28, 0x38, 0x29, 0x00, 0x00, 0x11, 0x2a, 0x37, 0x2b, 0x00, 0x3a, 0x28, 0x27, 0x29, 0x00,
                     0x25, 0x25, 0x25, 0x25, 0x25, 0x33, 0x1b, 0x1b, 0x1b, 0x1b, 0x31, 0x33, 0x00, 0x00, 0x00, 0x28,
                     0x35, 0x35, 0x35, 0x36, 0x28, 0x24, 0x26, 0x28, 0x14, 0x00, 0x00, 0x3b, 0x30, 0x28, 0x2a, 0x2a,
                     0x1a, 0x28, 0x29, 0x00, 0x2a, 0x28, 0x38, 0x28, 0x28, 0x10, 0x28, 0x24, 0x26, 0x00, 0x2a, 0x38,
                     0x25, 0x26, 0x1b, 0x1b, 0x00, 0x00, 0x38, 0x21, 0x23, 0x2b, 0x00, 0x00, 0x08, 0x10, 0x24, 0x25,
                     0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x3a, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
                     0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
                     0x25, 0x48, 0x25, 0x32, 0x32, 0x33, 0x2b, 0x00, 0x00, 0x00, 0x11, 0x00, 0x28, 0x24, 0x26, 0x29,
                     0x28, 0x10, 0x2a, 0x00, 0x00, 0x3b, 0x27, 0x00, 0x29, 0x00, 0x00, 0x00, 0x38, 0x30, 0x00, 0x00,
                     0x32, 0x32, 0x25, 0x25, 0x26, 0x2b, 0x00, 0x00, 0x00, 0x00, 0x3b, 0x27, 0x00, 0x00, 0x3a, 0x28,
                     0x28, 0x28, 0x38, 0x28, 0x28, 0x24, 0x25, 0x22, 0x23, 0x2b, 0x00, 0x3b, 0x37, 0x29, 0x08, 0x00,
                     0x00, 0x10, 0x00, 0x11, 0x00, 0x29, 0x2a, 0x28, 0x29, 0x11, 0x2a, 0x31, 0x33, 0x00, 0x3a, 0x28,
                     0x25, 0x26, 0x2b, 0x00, 0x00, 0x00, 0x2a, 0x31, 0x33, 0x2b, 0x00, 0x00, 0x68, 0x28, 0x24, 0x25,
                     0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x10, 0x00, 0x00, 0x39, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
                     0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
                     0x25, 0x25, 0x26, 0x21, 0x22, 0x23, 0x2b, 0x00, 0x3a, 0x67, 0x27, 0x2b, 0x2a, 0x24, 0x26, 0x38,
                     0x28, 0x29, 0x00, 0x00, 0x00, 0x3b, 0x30, 0x00, 0x00, 0x00, 0x00, 0x3a, 0x28, 0x30, 0x00, 0x00,
                     0x22, 0x23, 0x31, 0x32, 0x33, 0x2b, 0x00, 0x00, 0x00, 0x00, 0x3b, 0x30, 0x28, 0x39, 0x00, 0x2a,
                     0x38, 0x28, 0x29, 0x10, 0x29, 0x24, 0x48, 0x25, 0x26, 0x2b, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
                     0x00, 0x2a, 0x3b, 0x20, 0x2b, 0x3a, 0x16, 0x28, 0x3b, 0x20, 0x2b, 0x00, 0x11, 0x00, 0x00, 0x28,
                     0x25, 0x26, 0x2b, 0x00, 0x00, 0x00, 0x00, 0x1b, 0x1b, 0x00, 0x00, 0x2a, 0x38, 0x2a, 0x24, 0x25,
                     0x00, 0x00, 0x00, 0x00, 0x3a, 0x00, 0x28, 0x00, 0x00, 0x38, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
                     0x00, 0x00, 0x00, 0x00, 0x00, 0x49, 0x4a, 0x4b, 0x4c, 0x4d, 0x4e, 0x4f, 0x00, 0x00, 0x00, 0x00,
                     0x25, 0x25, 0x26, 0x24, 0x48, 0x26, 0x2b, 0x00, 0x2a, 0x38, 0x30, 0x2b, 0x12, 0x24, 0x26, 0x29,
                     0x38, 0x00, 0x00, 0x00, 0x00, 0x3b, 0x30, 0x00, 0x00, 0x00, 0x00, 0x00, 0x2a, 0x30, 0x3e, 0x14,
                     0x25, 0x25, 0x22, 0x22, 0x23, 0x2b, 0x00, 0x00, 0x00, 0x00, 0x3b, 0x30, 0x29, 0x00, 0x00, 0x00,
                     0x28, 0x29, 0x00, 0x00, 0x00, 0x24, 0x25, 0x25, 0x26, 0x2b, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
                     0x00, 0x00, 0x00, 0x1b, 0x00, 0x2a, 0x28, 0x28, 0x00, 0x1b, 0x00, 0x3b, 0x20, 0x2b, 0x11, 0x2a,
                     0x25, 0x26, 0x2b, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x29, 0x3b, 0x24, 0x48,
                     0x00, 0x00, 0x00, 0x00, 0x28, 0x67, 0x28, 0x00, 0x00, 0x10, 0x00, 0x39, 0x00, 0x00, 0x00, 0x00,
                     0x00, 0x00, 0x00, 0x00, 0x00, 0x59, 0x5a, 0x5b, 0x5c, 0x5d, 0x5e, 0x5f, 0x00, 0x00, 0x00, 0x00,
                     0x32, 0x32, 0x33, 0x31, 0x32, 0x26, 0x2b, 0x12, 0x00, 0x28, 0x30, 0x2b, 0x17, 0x31, 0x33, 0x00,
                     0x28, 0x39, 0x58, 0x68, 0x39, 0x3b, 0x30, 0x11, 0x11, 0x11, 0x11, 0x11, 0x11, 0x24, 0x22, 0x22,
                     0x25, 0x25, 0x48, 0x25, 0x26, 0x2b, 0x00, 0x00, 0x11, 0x00, 0x3b, 0x30, 0x2b, 0x00, 0x00, 0x00,
                     0x28, 0x11, 0x11, 0x11, 0x11, 0x24, 0x25, 0x48, 0x26, 0x2b, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
                     0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x11, 0x10, 0x67, 0x58, 0x11, 0x00, 0x1b, 0x3b, 0x20, 0x16,
                     0x48, 0x26, 0x11, 0x11, 0x11, 0x11, 0x00, 0x00, 0x00, 0x16, 0x00, 0x00, 0x00, 0x3b, 0x31, 0x25,
                     0x00, 0x00, 0x00, 0x00, 0x28, 0x38, 0x28, 0x76, 0x00, 0x28, 0x67, 0x28, 0x00, 0x00, 0x00, 0x00,
                     0x00, 0x00, 0x00, 0x00, 0x00, 0x69, 0x6a, 0x6b, 0x6c, 0x6d, 0x6e, 0x6f, 0x00, 0x00, 0x00, 0x00,
                     0x28, 0x00, 0x00, 0x00, 0x2a, 0x30, 0x11, 0x27, 0x00, 0x2a, 0x30, 0x2b, 0x00, 0x10, 0x10, 0x39,
                     0x28, 0x28, 0x38, 0x28, 0x34, 0x35, 0x32, 0x35, 0x35, 0x35, 0x35, 0x35, 0x35, 0x25, 0x25, 0x48,
                     0x25, 0x25, 0x25, 0x25, 0x26, 0x2b, 0x00, 0x3b, 0x27, 0x00, 0x3b, 0x30, 0x2b, 0x00, 0x00, 0x00,
                     0x28, 0x34, 0x35, 0x35, 0x35, 0x32, 0x32, 0x25, 0x26, 0x2b, 0x00, 0x00, 0x11, 0x00, 0x00, 0x00,
                     0x00, 0x00, 0x00, 0x00, 0x00, 0x3b, 0x20, 0x28, 0x28, 0x38, 0x27, 0x2b, 0x16, 0x00, 0x1b, 0x00,
                     0x25, 0x25, 0x23, 0x21, 0x22, 0x23, 0x2b, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x1b, 0x24,
                     0x00, 0x00, 0x00, 0x00, 0x2a, 0x28, 0x28, 0x21, 0x23, 0x28, 0x38, 0x29, 0x00, 0x00, 0x00, 0x00,
                     0x00, 0x00, 0x00, 0x00, 0x00, 0x79, 0x7a, 0x7b, 0x7c, 0x7d, 0x7e, 0x7f, 0x00, 0x00, 0x00, 0x00,
                     0x29, 0x00, 0x11, 0x00, 0x00, 0x31, 0x35, 0x26, 0x2b, 0x00, 0x31, 0x35, 0x35, 0x35, 0x35, 0x35,
                     0x29, 0x00, 0x2a, 0x00, 0x00, 0x10, 0x28, 0x28, 0x28, 0x28, 0x29, 0x00, 0x3b, 0x24, 0x25, 0x25,
                     0x32, 0x32, 0x32, 0x32, 0x26, 0x2b, 0x16, 0x3b, 0x30, 0x00, 0x3b, 0x30, 0x00, 0x00, 0x00, 0x00,
                     0x29, 0x1b, 0x1b, 0x1b, 0x1b, 0x1b, 0x3b, 0x24, 0x26, 0x2b, 0x00, 0x3b, 0x27, 0x2b, 0x00, 0x00,
                     0x00, 0x11, 0x00, 0x00, 0x00, 0x00, 0x1b, 0x2a, 0x28, 0x28, 0x37, 0x2b, 0x00, 0x00, 0x00, 0x00,
                     0x32, 0x32, 0x33, 0x31, 0x32, 0x33, 0x2b, 0x00, 0x00, 0x11, 0x11, 0x00, 0x00, 0x00, 0x3b, 0x24,
                     0x00, 0x00, 0x00, 0x68, 0x38, 0x28, 0x21, 0x25, 0x25, 0x23, 0x28, 0x39, 0x3a, 0x00, 0x00, 0x00,
                     0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
                     0x00, 0x3b, 0x27, 0x2b, 0x00, 0x2a, 0x38, 0x30, 0x2b, 0x00, 0x00, 0x00, 0x2a, 0x28, 0x39, 0x3b,
                     0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x2a, 0x28, 0x38, 0x28, 0x28, 0x67, 0x21, 0x25, 0x25, 0x25,
                     0x1b, 0x1b, 0x1b, 0x1b, 0x37, 0x2b, 0x00, 0x3b, 0x30, 0x39, 0x3b, 0x30, 0x16, 0x00, 0x00, 0x00,
                     0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x3b, 0x24, 0x26, 0x2b, 0x17, 0x3b, 0x30, 0x2b, 0x00, 0x00,
                     0x3b, 0x20, 0x2b, 0x11, 0x00, 0x00, 0x00, 0x11, 0x00, 0x29, 0x1b, 0x00, 0x00, 0x00, 0x00, 0x3a,
                     0x1b, 0x1b, 0x1b, 0x1b, 0x1b, 0x1b, 0x00, 0x11, 0x11, 0x21, 0x23, 0x11, 0x00, 0x00, 0x3b, 0x24,
                     0x00, 0x00, 0x00, 0x2a, 0x28, 0x21, 0x25, 0x48, 0x25, 0x25, 0x23, 0x28, 0x38, 0x68, 0x00, 0x00,
                     0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
                     0x08, 0x3b, 0x30, 0x2b, 0x00, 0x00, 0x28, 0x30, 0x11, 0x11, 0x11, 0x11, 0x00, 0x28, 0x38, 0x3b,
                     0x11, 0x11, 0x11, 0x11, 0x11, 0x00, 0x00, 0x28, 0x29, 0x00, 0x29, 0x28, 0x24, 0x25, 0x48, 0x25,
                     0x00, 0x00, 0x00, 0x3a, 0x28, 0x00, 0x00, 0x3b, 0x30, 0x28, 0x3b, 0x37, 0x00, 0x00, 0x00, 0x00,
                     0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x3b, 0x24, 0x26, 0x11, 0x11, 0x11, 0x30, 0x2b, 0x00, 0x00,
                     0x00, 0x1b, 0x3b, 0x20, 0x2b, 0x00, 0x3b, 0x27, 0x2b, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x28,
                     0x2b, 0x01, 0x00, 0x00, 0x00, 0x00, 0x3b, 0x21, 0x22, 0x25, 0x32, 0x36, 0x2b, 0x00, 0x3b, 0x31,
                     0x58, 0x58, 0x68, 0x28, 0x29, 0x24, 0x25, 0x25, 0x25, 0x25, 0x26, 0x10, 0x28, 0x28, 0x68, 0x00,
                     0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
                     0x00, 0x3b, 0x37, 0x2b, 0x00, 0x00, 0x2a, 0x31, 0x35, 0x35, 0x35, 0x36, 0x00, 0x28, 0x29, 0x3b,
                     0x22, 0x22, 0x22, 0x22, 0x23, 0x11, 0x11, 0x20, 0x2b, 0x00, 0x00, 0x2a, 0x31, 0x32, 0x25, 0x25,
                     0x00, 0x00, 0x00, 0x10, 0x38, 0x29, 0x00, 0x3b, 0x30, 0x28, 0x28, 0x28, 0x00, 0x00, 0x00, 0x00,
                     0x11, 0x11, 0x11, 0x11, 0x39, 0x00, 0x11, 0x24, 0x25, 0x22, 0x22, 0x22, 0x33, 0x2b, 0x00, 0x00,
                     0x01, 0x00, 0x00, 0x1b, 0x00, 0x00, 0x3b, 0x30, 0x2b, 0x00, 0x00, 0x00, 0x00, 0x58, 0x68, 0x28,
                     0x2b, 0x17, 0x00, 0x00, 0x00, 0x00, 0x3b, 0x24, 0x25, 0x33, 0x1b, 0x1b, 0x00, 0x00, 0x00, 0x1b,
                     0x28, 0x10, 0x28, 0x38, 0x00, 0x31, 0x32, 0x25, 0x25, 0x48, 0x26, 0x29, 0x00, 0x2a, 0x28, 0x00,
                     0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
                     0x39, 0x00, 0x1b, 0x00, 0x00, 0x00, 0x00, 0x1b, 0x1b, 0x1b, 0x1b, 0x1b, 0x00, 0x2a, 0x00, 0x3b,
                     0x32, 0x32, 0x32, 0x32, 0x32, 0x35, 0x36, 0x1b, 0x00, 0x00, 0x00, 0x00, 0x1b, 0x1b, 0x31, 0x25,
                     0x00, 0x00, 0x00, 0x00, 0x28, 0x00, 0x00, 0x3b, 0x30, 0x28, 0x38, 0x29, 0x00, 0x00, 0x00, 0x00,
                     0x22, 0x22, 0x22, 0x23, 0x28, 0x38, 0x34, 0x32, 0x32, 0x32, 0x32, 0x33, 0x2b, 0x00, 0x00, 0x00,
                     0x23, 0x39, 0x00, 0x00, 0x00, 0x00, 0x3b, 0x37, 0x2b, 0x00, 0x00, 0x00, 0x00, 0x2a, 0x10, 0x28,
                     0x11, 0x11, 0x11, 0x11, 0x00, 0x00, 0x3b, 0x31, 0x33, 0x1b, 0x00, 0x3a, 0x00, 0x16, 0x00, 0x00,
                     0x00, 0x2a, 0x28, 0x39, 0x3f, 0x21, 0x23, 0x24, 0x25, 0x32, 0x33, 0x20, 0x00, 0x00, 0x28, 0x00,
                     0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
                     0x28, 0x29, 0x00, 0x00, 0x01, 0x00, 0x14, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x3b,
                     0x39, 0x01, 0x3d, 0x00, 0x00, 0x2a, 0x28, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x28, 0x24,
                     0x00, 0x00, 0x00, 0x68, 0x28, 0x67, 0x00, 0x3b, 0x30, 0x00, 0x2a, 0x28, 0x67, 0x00, 0x00, 0x00,
                     0x25, 0x25, 0x25, 0x26, 0x00, 0x28, 0x28, 0x00, 0x3a, 0x10, 0x28, 0x2a, 0x00, 0x16, 0x00, 0x3a,
                     0x26, 0x28, 0x00, 0x00, 0x00, 0x00, 0x00, 0x1b, 0x00, 0x00, 0x00, 0x39, 0x3a, 0x28, 0x38, 0x28,
                     0x22, 0x22, 0x22, 0x23, 0x2b, 0x00, 0x00, 0x1b, 0x1b, 0x00, 0x00, 0x38, 0x00, 0x00, 0x00, 0x68,
                     0x00, 0x00, 0x21, 0x22, 0x22, 0x25, 0x26, 0x31, 0x33, 0x21, 0x22, 0x23, 0x28, 0x39, 0x28, 0x67,
                     0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
                     0x10, 0x67, 0x58, 0x3a, 0x21, 0x22, 0x23, 0x11, 0x11, 0x11, 0x11, 0x11, 0x00, 0x12, 0x00, 0x3b,
                     0x22, 0x22, 0x23, 0x39, 0x00, 0x10, 0x28, 0x39, 0x00, 0x00, 0x00, 0x00, 0x08, 0x3a, 0x10, 0x31,
                     0x01, 0x00, 0x3a, 0x38, 0x28, 0x29, 0x00, 0x3b, 0x37, 0x00, 0x00, 0x38, 0x29, 0x00, 0x00, 0x00,
                     0x25, 0x48, 0x25, 0x26, 0x00, 0x2a, 0x28, 0x28, 0x28, 0x38, 0x29, 0x00, 0x00, 0x00, 0x00, 0x28,
                     0x26, 0x38, 0x39, 0x12, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x3a, 0x28, 0x28, 0x28, 0x28, 0x10,
                     0x25, 0x48, 0x25, 0x26, 0x2b, 0x16, 0x00, 0x00, 0x39, 0x00, 0x00, 0x28, 0x3a, 0x00, 0x3a, 0x28,
                     0x01, 0x00, 0x31, 0x25, 0x25, 0x48, 0x25, 0x22, 0x22, 0x25, 0x25, 0x25, 0x23, 0x10, 0x38, 0x28,
                     0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
                     0x28, 0x38, 0x28, 0x28, 0x24, 0x25, 0x25, 0x22, 0x22, 0x22, 0x22, 0x23, 0x00, 0x17, 0x00, 0x3b,
                     0x25, 0x25, 0x26, 0x28, 0x3a, 0x28, 0x38, 0x28, 0x00, 0x00, 0x00, 0x00, 0x00, 0x38, 0x28, 0x28,
                     0x23, 0x00, 0x10, 0x28, 0x28, 0x00, 0x00, 0x00, 0x38, 0x00, 0x00, 0x28, 0x10, 0x00, 0x00, 0x00,
                     0x25, 0x25, 0x25, 0x26, 0x17, 0x17, 0x28, 0x38, 0x28, 0x00, 0x00, 0x00, 0x00, 0x00, 0x3a, 0x28,
                     0x26, 0x28, 0x10, 0x27, 0x39, 0x00, 0x00, 0x00, 0x00, 0x2a, 0x28, 0x28, 0x38, 0x28, 0x28, 0x28,
                     0x25, 0x25, 0x48, 0x26, 0x2b, 0x00, 0x00, 0x3a, 0x38, 0x00, 0x3a, 0x28, 0x10, 0x28, 0x38, 0x28,
                     0x21, 0x22, 0x23, 0x24, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x48, 0x25, 0x25, 0x22, 0x22, 0x23,
                     0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00};
